/**
 * ValuesAction.java
 * eu.gronos.kostenrechner (Kostenrechner)
 */
package eu.gronos.kostenrechner;

import javax.swing.AbstractAction;
import javax.swing.JComponent;
import javax.swing.KeyStroke;

/**
 * Von {@link AbstractAction} abgeleitete Klasse, deren Konstruktoren bereits
 * Felder setzen lassen.
 *
 * @author Peter Schuster (setrok)
 * @date 31.08.2014
 *
 */
@SuppressWarnings("serial")
abstract class BeschriebeneAktion extends AbstractAction {

	/**
	 * Ein Konstruktor, der bereits Felder setzen lässt.
	 * 
	 * @param name
	 *            the name ({@link javax.swing.Action#NAME}) for the action; a
	 *            value of null is ignored
	 * @param shortDescription
	 *            ({@link javax.swing.Action#SHORT_DESCRIPTION}) The key used
	 *            for storing a short String description for the action, used
	 *            for tooltip text.
	 * @param mnemonic
	 *            ({@link javax.swing.Action#MNEMONIC_KEY}) The key used for
	 *            storing an Integer that corresponds to one of the KeyEvent key
	 *            codes. The value is commonly used to specify a mnemonic.
	 *            KeyEvent.getExtendedKeyCodeForChar('\u0444')) sets the
	 *            mnemonic of myAction to Cyrillic letter "Ef".
	 * @param actionCommandKey
	 *            ({@link javax.swing.Action#ACTION_COMMAND_KEY}) The key used
	 *            to determine the command String for the ActionEvent that will
	 *            be created when an Action is going to be notified as the
	 *            result of residing in a Keymap associated with a
	 *            {@link JComponent}.
	 * @param acceleratorKey
	 *            ({@link javax.swing.Action#ACCELERATOR_KEY}) The key used for
	 *            storing a KeyStroke to be used as the accelerator for the
	 *            action.
	 */
	public BeschriebeneAktion(String name, String shortDescription,
			int mnemonic, String actionCommandKey, KeyStroke acceleratorKey) {
		this(name, shortDescription, mnemonic, actionCommandKey);
		putValue(ACCELERATOR_KEY, acceleratorKey);
	}

	/**
	 * Ein Konstruktor, der bereits Felder setzen lässt.
	 * 
	 * @param name
	 *            the name ({@link javax.swing.Action#NAME}) for the action; a
	 *            value of null is ignored
	 * @param shortDescription
	 *            ({@link javax.swing.Action#SHORT_DESCRIPTION}) The key used
	 *            for storing a short String description for the action, used
	 *            for tooltip text.
	 * @param mnemonic
	 *            ({@link javax.swing.Action#MNEMONIC_KEY}) The key used for
	 *            storing an Integer that corresponds to one of the KeyEvent key
	 *            codes. The value is commonly used to specify a mnemonic.
	 *            KeyEvent.getExtendedKeyCodeForChar('\u0444')) sets the
	 *            mnemonic of myAction to Cyrillic letter "Ef".
	 * @param actionCommandKey
	 *            ({@link javax.swing.Action#ACTION_COMMAND_KEY}) The key used
	 *            to determine the command String for the ActionEvent that will
	 *            be created when an Action is going to be notified as the
	 *            result of residing in a Keymap associated with a
	 *            {@link JComponent}.
	 */
	public BeschriebeneAktion(String name, String shortDescription,
			int mnemonic, String actionCommandKey) {
		this(name, shortDescription, mnemonic);
		putValue(ACTION_COMMAND_KEY, actionCommandKey);
	}

	/**
	 * Ein Konstruktor, der bereits Felder setzen lässt.
	 * 
	 * @param name
	 *            the name ({@link javax.swing.Action#NAME}) for the action; a
	 *            value of null is ignored
	 * @param shortDescription
	 *            ({@link javax.swing.Action#SHORT_DESCRIPTION}) The key used
	 *            for storing a short String description for the action, used
	 *            for tooltip text.
	 * @param mnemonic
	 *            ({@link javax.swing.Action#MNEMONIC_KEY}) The key used for
	 *            storing an Integer that corresponds to one of the KeyEvent key
	 *            codes. The value is commonly used to specify a mnemonic.
	 *            KeyEvent.getExtendedKeyCodeForChar('\u0444')) sets the
	 *            mnemonic of myAction to Cyrillic letter "Ef".
	 */
	public BeschriebeneAktion(String name, String shortDescription, int mnemonic) {
		this(name, shortDescription);
		putValue(MNEMONIC_KEY, mnemonic);
	}

	/**
	 * Ein Konstruktor, der bereits Felder setzen lässt.
	 * 
	 * @param name
	 *            the name ({@link javax.swing.Action#NAME}) for the action; a
	 *            value of null is ignored
	 * @param shortDescription
	 *            ({@link javax.swing.Action#SHORT_DESCRIPTION}) The key used
	 *            for storing a short String description for the action, used
	 *            for tooltip text.
	 */
	public BeschriebeneAktion(String name, String shortDescription) {
		super(name);
		putValue(SHORT_DESCRIPTION, shortDescription);
	}
}
