/**
 * FehlerDialog.java
 * eu.gronos.kostenrechner (Kostenrechner)
 */
package eu.gronos.kostenrechner;

import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

/**
 * Eine Klasse, die Fehlermeldungen ausführlicher darstellt.
 *
 * @author Peter Schuster (setrok)
 * @date 26.08.2014
 *
 */
class FehlerDialog extends HinzufuegenDialog<Boolean> {

	private static final long serialVersionUID = 306283812188663774L;
	private String meldung;
	// private StackTraceElement[] stackTrace;
	// private String localizedMessage;
	// this.stackTrace = stackTrace;
	// this.localizedMessage = localizedMessage;
	private Throwable throwable;
	static final String FEHLER_BLANKO = "Fehler";

	/**
	 * Der Konstruktor initialisiert den Dialog und gibt eine StackTrace aus.
	 * 
	 * @param title
	 *            den Titel des Dialogs
	 * @param meldung
	 *            die Fehlermeldung
	 * @param throwable
	 *            das {@link Throwable} (Oberklasse von {@link Exception}), das
	 *            geworfen wurde.
	 */
	public FehlerDialog(String title, String meldung, Throwable throwable) {
		super(Kostenrechner.selbst, title);
		this.meldung = meldung;
		this.throwable = throwable;
		super.setOkButtonToBeFocussed(true);
		throwable.printStackTrace();
	}

	/**
	 * Die Methode füllt das contentPane mit einem Icon-Label, einer JTextArea
	 * für die eigentliche Meldung und einer JTextArea im JScrollPane für den
	 * StackTrace.
	 * 
	 * @see eu.gronos.kostenrechner.HinzufuegenDialog#fuelleContentPane()
	 */
	@Override
	protected void fuelleContentPane() {
		JPanel meldungPane = new JPanel();
		meldungPane.setLayout(new FlowLayout(FlowLayout.LEFT));

		JLabel lblIcon = new JLabel(new ImageIcon(getClass().getClassLoader()
				.getResource("resources/rechnerhammer-rot.png")));
		JTextArea jtaMeldung = new JTextArea(meldung);
		jtaMeldung.setRows(2);
		jtaMeldung.setEditable(false);
		jtaMeldung.setOpaque(false);

		StringBuffer sb = new StringBuffer();
		if (throwable != null) {
			sb.append(throwable.getLocalizedMessage() + "\n");
			for (StackTraceElement ste : throwable.getStackTrace()) {
				sb.append("\t" + ste.toString() + "\n");
			}
		}
		JTextArea jtaStackTrace = new JTextArea();
		jtaStackTrace.setText(sb.toString());
		jtaStackTrace.setCaretPosition(0);
		jtaStackTrace.setForeground(Color.RED);
		jtaStackTrace.setEditable(false);
		jtaStackTrace.setRows(7);
		JScrollPane scpStackTrace = new JScrollPane(jtaStackTrace);
		scpStackTrace.setVisible(Kostenrechner.debug);

		meldungPane.add(lblIcon);
		meldungPane.add(jtaMeldung);
		contentPanel.add(meldungPane, GitterBeutelBeschraenkungen.getInstance(
				0, 0, 1, 1, GridBagConstraints.HORIZONTAL, false));
		contentPanel.add(scpStackTrace, GitterBeutelBeschraenkungen
				.getInstance(0, 1, 1, 1, GridBagConstraints.BOTH, true));
	}

	@Override
	protected boolean parseEingabe() {
		return true;
	}

	@Override
	protected Boolean baueRueckgabewert() {
		return Boolean.TRUE;
	}

}
