/**
 * GebuehrHinzufuegenDialog.java
 * eu.gronos.kostenrechner (Kostenrechner)
 */
package eu.gronos.kostenrechner;

import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.KeyEvent;

import javax.swing.JComboBox;
import javax.swing.JFormattedTextField;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.SwingConstants;

/**
 * Dialog zum Hinzufügen eines Gebührentatbestands (oder Auslagentatbestands)
 * 
 * @author Peter Schuster (setrok)
 * @date 16.06.2014
 */
class GebuehrHinzufuegenDialog extends HinzufuegenDialog<GebuehrenTatbestand> {
	private static final long serialVersionUID = 6033596324746359222L;
	private JComboBox<GebuehrenTatbestand> cbGebuehrenListe;
	private JFormattedTextField ftfAuslagenHoehe;
	// NumberFormat format;
	// NumberFormatter formatter;
	private JLabel lblGebuehrenListe;
	private JLabel lblAuslagenHoehe;
	private GebuehrenTatbestand[] alleGebTb;
	private static final String ANZAHL_TEXT = "Anzahl der zusätzlich Vertretenen:";
	private static final String AUSLAGEN_HOEHE_TEXT = "Höhe der Auslage (EUR):";

	// protected boolean isOk;
	// private JPanel contentPane;
	// private EmptyBorder border;

	/**
	 * Dieser Konstruktor lässt aus allen bekannten Gebührentatbeständen
	 * auswählen.
	 * 
	 * @param owner
	 *            der JFrame, der den Dialog aufrufen soll
	 * @param title
	 *            der anzuzeigende Titel
	 * @see eu.gronos.kostenrechner.HinzufuegenDialog#HinzufuegenDialog(JFrame,
	 *      String)
	 * @see javax.swing.JDialog#JDialog(Frame,String,boolean)
	 */
	public GebuehrHinzufuegenDialog(JFrame owner, String title) {
		this(owner, title, GebuehrenTabelle.mergeAllGebuehrenTatbestaende(
				GerichtsGebuehrenTabelle.getAllGebuehrenTatbestaende(),
				AnwaltsGebuehrenTabelle.getAllGebuehrenTatbestaende()));
	}

	/**
	 * Der Standardkonstruktor baut einen Dialog, bei dem aus den übergegebenen
	 * Gebührentatbeständen ausgewählt werden kann.
	 * 
	 * @param owner
	 *            der JFrame, der den Dialog aufrufen soll
	 * @param title
	 *            der anzuzeigende Titel
	 * @param alleGebTb
	 *            ein Array GebuehrenTatbestand[] mit den GebuehrenTatbeständen,
	 *            die zur Auswahl stehen soll.
	 * @see eu.gronos.kostenrechner.HinzufuegenDialog#HinzufuegenDialog(JFrame,
	 *      String)
	 * @see javax.swing.JDialog#JDialog(Frame,String,boolean)
	 */
	public GebuehrHinzufuegenDialog(JFrame owner, String title,
			GebuehrenTatbestand[] alleGebTb) {
		super(owner, title);
		this.alleGebTb = alleGebTb;
	}

	/**
	 * Die Methode showDialog dient dazu, den Dialog aufzurufen, auf eine
	 * Eingabe zu warten und dann einen GebuehrenTatbestand (bzw.
	 * AuslagenTatbestand) zurückzugeben.
	 * 
	 * @return einen GebuehrenTatbestand (GebuehrenSatzTatbestand bzw.
	 *         AuslagenTatbestand) mit den Werten der Komponenten
	 * @see eu.gronos.kostenrechner.HinzufuegenDialog#baueRueckgabewert()
	 */
	@Override
	protected GebuehrenTatbestand baueRueckgabewert() {
		GebuehrenTatbestand gt = (GebuehrenTatbestand) cbGebuehrenListe
				.getSelectedItem();
		// Bei AuslagenTatbestand und GebuehrenErhoehungsTatbestand wird geklont
		if (gt instanceof AuslagenTatbestand
				&& ((AuslagenTatbestand) gt).getBetrag() < 0) {
			double auslagen = Double.parseDouble(ftfAuslagenHoehe.getText());
			gt = new AuslagenTatbestand(gt.getBezeichnung(), auslagen,
					gt.getGebuehrenKlasse());
		}
		if (gt instanceof GebuehrenErhoehungsTatbestand
				&& ((GebuehrenErhoehungsTatbestand) gt).getAnzahl() < 0) {
			GebuehrenErhoehungsTatbestand getb = ((GebuehrenErhoehungsTatbestand) gt);
			int anzahl = Integer.parseInt(ftfAuslagenHoehe.getText());
			gt = new GebuehrenErhoehungsTatbestand(gt.getBezeichnung(),
					gt.getGebuehrenKlasse(), getb.getJeweilsSatz(),
					getb.getMaxSatz(), anzahl);
		}
		return gt;
	}

	/**
	 * Die Methode adjustVisibility dient dazu, die Beschreibbarkeit des
	 * Eingabefelds für die Auslagenhöhe an die Art des GebührenTatbestands
	 * anzupassen.
	 * 
	 */
	void adjustAuslagenHoeheVisibility() {
		GebuehrenTatbestand gt = (GebuehrenTatbestand) cbGebuehrenListe
				.getSelectedItem();
		if (gt instanceof AuslagenTatbestand
				&& ((AuslagenTatbestand) gt).getBetrag() <= 0.0) {
			aktiviereFtfAuslagenHoehe();
			lblAuslagenHoehe.setText(AUSLAGEN_HOEHE_TEXT);
		} else if (gt instanceof GebuehrenErhoehungsTatbestand
				&& ((GebuehrenErhoehungsTatbestand) gt).getAnzahl() < 0) {
			aktiviereFtfAuslagenHoehe();
			lblAuslagenHoehe.setText(ANZAHL_TEXT);
		} else
			ftfAuslagenHoehe.setEnabled(false);
	}

	/**
	 * Die Methode dient dazu, das Eingabefeld zu aktivieren
	 * 
	 */
	private void aktiviereFtfAuslagenHoehe() {
		ftfAuslagenHoehe.setEnabled(true);
		if (ftfAuslagenHoehe.getText() == null
				|| "".equals(ftfAuslagenHoehe.getText()))
			ftfAuslagenHoehe.setText("0");
	}

	/**
	 * @see eu.gronos.kostenrechner.HinzufuegenDialog#fuelleContentPane()
	 */
	@Override
	protected void fuelleContentPane() {
		{
			lblGebuehrenListe = new JLabel("Gebühren-/Auslagentatbestand:",
					SwingConstants.RIGHT);
			contentPanel.add(lblGebuehrenListe, GitterBeutelBeschraenkungen
					.getInstance(0, 0, 1, 1, GridBagConstraints.HORIZONTAL,
							false));
			cbGebuehrenListe = new JComboBox<GebuehrenTatbestand>(alleGebTb);
			setMnemonicLabelFor(lblGebuehrenListe, cbGebuehrenListe,
					KeyEvent.VK_G);
			contentPanel.add(cbGebuehrenListe, GitterBeutelBeschraenkungen
					.getInstance(1, 0, 1, 1, GridBagConstraints.HORIZONTAL,
							false));
			cbGebuehrenListe.addItemListener(new ItemListener() {

				@Override
				public void itemStateChanged(ItemEvent e) {
					adjustAuslagenHoeheVisibility();
				}

			});
		}
		{

			lblAuslagenHoehe = new JLabel(AUSLAGEN_HOEHE_TEXT,
					SwingConstants.RIGHT);
			contentPanel.add(lblAuslagenHoehe, GitterBeutelBeschraenkungen
					.getInstance(0, 1, 1, 1, GridBagConstraints.HORIZONTAL,
							false));

			ftfAuslagenHoehe = new JFormattedTextField(formatter);
			setEnterAction(ftfAuslagenHoehe, getOkAction());
			setMnemonicLabelFor(lblAuslagenHoehe, ftfAuslagenHoehe,
					KeyEvent.VK_H);
			contentPanel.add(ftfAuslagenHoehe, GitterBeutelBeschraenkungen
					.getInstance(1, 1, 1, 1, GridBagConstraints.HORIZONTAL,
							false));
			adjustAuslagenHoeheVisibility();
		}
	}

	/**
	 * @see eu.gronos.kostenrechner.HinzufuegenDialog#parseEingabe()
	 */
	@Override
	protected boolean parseEingabe() {
		GebuehrenTatbestand gt = (GebuehrenTatbestand) cbGebuehrenListe
				.getSelectedItem();
		if (gt instanceof AuslagenTatbestand
				&& ((AuslagenTatbestand) gt).getBetrag() < 0) {
			try {
				double auslagen = Double
						.parseDouble(ftfAuslagenHoehe.getText());
				if (auslagen < 0)
					throw new NumberFormatException(
							HinzufuegenDialog.FEHLER_AUSLAGENHOEHE_NEGATIV);
			} catch (NumberFormatException | NullPointerException ne) {
				Kostenrechner.zeigeFehler(FehlerDialog.FEHLER_BLANKO,
						ne.getLocalizedMessage(), ne);
//				ne.printStackTrace();
				return false;
			}
		}
		if (gt instanceof GebuehrenErhoehungsTatbestand
				&& ((GebuehrenErhoehungsTatbestand) gt).getAnzahl() < 0) {
			try {
				int anzahl = Integer.parseInt(ftfAuslagenHoehe.getText());
				if (anzahl < 0)
					throw new NumberFormatException(HinzufuegenDialog.FEHLER_ANZAHL_NEGATIV);
			} catch (NumberFormatException | NullPointerException ne) {
				Kostenrechner.zeigeFehler(FehlerDialog.FEHLER_BLANKO,
						ne.getLocalizedMessage(), ne);
//				ne.printStackTrace();
				return false;
			}
		}
		return true;
	}
}
