/**
 * TenorUtils.java
 * eu.gronos.kostenrechner (Kostenrechner)
 */
package eu.gronos.kostenrechner;

import java.util.ArrayList;
import java.util.Arrays;

/**
 * Hält Methoden zur Tenorerzeugung bereit.
 * 
 * @author Peter Schuster (setrok)
 * @version 19.06.2014
 * 
 */
class TenorUtils {

	/**
	 * Konstruktor: nix Konstruktor (private Sichtbarkeit)
	 */
	private TenorUtils() {
		// nix Konstruktor
	}

	/**
	 * Die Methode hatStattHaben dient dazu, in einem String das Wort haben
	 * durch das Wort hat zu ersetzen, wenn nur einer die Kosten trägt. Das
	 * erkennt die Methode daran, dass weder ein Komma ", " noch ein "und" in
	 * dem Satz vorkommt.
	 * 
	 * @param satz
	 *            ein String mit dem Satz, um den es geht.
	 * @return der gleiche Satz, unter Berücksichtigung des Singulars, wo es
	 *         gerade passt.
	 */
	static String hatStattHaben(String satz) {
		if (!satz.contains(UrteilsTenorierend.KOMMA)
				&& !satz.contains(UrteilsTenorierend.UND)
				&& satz.contains(UrteilsTenorierend.HABEN)) {
			final int wo = satz.indexOf(UrteilsTenorierend.HABEN);
			final String davor = satz.substring(0, wo);
			final String danach = satz.substring(wo
					+ UrteilsTenorierend.HABEN.length());
			return davor + UrteilsTenorierend.HAT + danach;
		} else
			return satz;
	}

	/**
	 * Methode, um den ersten Buchstaben in einen Großbuchstaben umzuwandeln.
	 * 
	 * @param satz
	 *            ein String mit dem Satz, um dessen Anfang es geht.
	 * @return den gleichen String, aber mit einem Großbuchstaben am Anfang.
	 */
	static String satzBeginn(String satz) {
		String zwischen = "";
		if (satz != null && satz.length() > 0)
			zwischen = satz.substring(0, 1).toUpperCase() + satz.substring(1);
		return zwischen;
	}

	/**
	 * Die Methode entfernt im übergebenen <code>satz</code> das letzte Komma,
	 * sofern dieser auf ein Komma endet.
	 * 
	 * @param satz
	 *            eine Zeichenkette als String
	 * @return denselben String, ohne ein etwaiges Komma am Ende.
	 */
	static String letztesKommaWeg(String satz) {
		String zwischen = satz;
		if (satz != null && satz.trim().endsWith(","))
			zwischen = satz.substring(0, satz.lastIndexOf(","));
		return zwischen;
	}

	/**
	 * Die Methode ersetzt das letzte Vorkommen von ", " durch ein " und ".
	 * 
	 * @param satz
	 *            eine Zeichenkette als String
	 * @return
	 */
	static String undStattKomma(String satz) {
		String zwischen = satz;
		int j = satz.lastIndexOf(UrteilsTenorierend.KOMMA);// (", ");
		if (j > 0 && j < satz.length()) {
			zwischen = satz.substring(0, j) + UrteilsTenorierend.UND
					+ satz.substring(j + 2);
		}
		return zwischen;
	}

	/**
	 * Die Methode entscheidet, ob wird oder werden als Pluralform angemessen
	 * ist.
	 * 
	 * @param plural
	 *            true, wenn die Pluralform verwendet werden soll
	 * @return "wird" oder "werden" als String
	 */
	static String getWirdWerden(boolean plural) {
		return plural ? UrteilsTenorierend.WERDEN : UrteilsTenorierend.WIRD;
	}

	/**
	 * Die Methode verändert die Satzstellung bei gesamtschuldnerischer
	 * Verurteilung
	 * 
	 * @param satz
	 *            der Satz, der verbessert werden soll, als String
	 * @return derselbe Satz mit verbesserter Wortstellung
	 */
	static String verbessereGesamtschuldner(String satz) {
		return satz.replace(UrteilsTenorierend.GESAMTSCHULDNERISCH_FALSCH,
				UrteilsTenorierend.GESAMTSCHULDNERISCH_RICHTIG).replace(
				UrteilsTenorierend.GESAMTSCHULDNERISCH_DARUEBER_FALSCH,
				UrteilsTenorierend.GESAMTSCHULDNERISCH_DARUEBER_RICHTIG);
	}

	/**
	 * Hänge einem Array einen Wert an
	 * 
	 * Java, Mehr als eine Insel, Kapitel 3.8.19: Hänge zwei Arrays aneinander.
	 * Das ist ein gutes Beispiel für copyOf(), wenn das Zielfeld größer ist.
	 * Die Klasse Arrays bietet eine Reihe von copyOf()- bzw.
	 * copyOfRange()-Methoden, die gegenüber clone() den Vorteil haben, dass sie
	 * auch Bereichsangaben erlauben und das neue Feld größer machen können; im
	 * letzten Fall füllen die Methoden das Feld je nach Typ mit null, false
	 * oder 0.
	 * 
	 * @url 
	 *      "http://openbook.galileocomputing.de/javainsel/javainsel_03_008.html"
	 */
	public static Object[] appendArray(Object[] objekte, Object wert) {
		Object[] array = Arrays.copyOf(objekte, objekte.length + 1);
		System.arraycopy(new Object[] { wert }, 0, array, objekte.length, 1);
		return array;
	}

	/**
	 * Java, Mehr als eine Insel, Kapitel 3.8.19: Hänge zwei Arrays aneinander.
	 * Das ist ein gutes Beispiel für copyOf(), wenn das Zielfeld größer ist.
	 * Die Klasse Arrays bietet eine Reihe von copyOf()- bzw.
	 * copyOfRange()-Methoden, die gegenüber clone() den Vorteil haben, dass sie
	 * auch Bereichsangaben erlauben und das neue Feld größer machen können; im
	 * letzten Fall füllen die Methoden das Feld je nach Typ mit null, false
	 * oder 0.
	 * 
	 * @url 
	 *      "http://openbook.galileocomputing.de/javainsel/javainsel_03_008.html"
	 */
	public static Object[] concat(Object[] eins, Object[] zwei) {
		Object[] drei = Arrays.copyOf(eins, eins.length + zwei.length);
		System.arraycopy(zwei, 0, drei, eins.length, zwei.length);
		return drei;
	}

	/**
	 * Die Methode konvertiert die {@link ArrayList}&lt;{@link Object}[]&gt; zu
	 * den eigentlichen Tabellendaten für
	 * {@link Tabulierend#getTableCellValues()}. Die erste Zeile mit den
	 * Kopfdaten wird dabei übersprungen.
	 * 
	 * @param zeilenListe
	 *            eine {@link ArrayList}&lt;{@link Object}[]&gt;
	 * @return ein Array Object[][]
	 */
	static Object[][] convertTableCellValues(ArrayList<Object[]> zeilenListe) {
		if (zeilenListe == null || zeilenListe.size() < 1)
			return null;
		Object[][] tableCellValues = new Object[zeilenListe.size() - 1][5];
		for (int i = 0; i < tableCellValues.length; i++)
			tableCellValues[i] = zeilenListe.get(i + 1);
		return tableCellValues;
	}

	/**
	 * Die Methode wandelt ein Array Object[] mit String und Double als Inhalt
	 * in eine Tab-separierte Textzeile (String) um.
	 * 
	 * @param zeile
	 *            ein Array Object[]
	 * @return eine Tab-separierte Textzeile (String)
	 */
	static String zeileZuText(Object[] zeile) {
		StringBuffer text = new StringBuffer();
		for (int i = 0; i < zeile.length; i++) {
			if (zeile[i] instanceof String)
				text.append((String) zeile[i]);
			else if (zeile[i] instanceof Double)
				text.append(String.format("%,.2f", (Double) zeile[i]));
			/* Tabulator oder Zeilenumbruch. */
			if (i == zeile.length - 1)
				text.append("\n");
			else
				text.append("\t");
		}
		return text.toString();
	}

	/**
	 * Die Methode konvertiert die erste Zeile der {@link ArrayList}&lt;
	 * {@link Object}[]&gt; zu den Kopfdaten für
	 * {@link Tabulierend#getColumnNames()}.
	 * 
	 * @param zeilenListe
	 *            eine {@link ArrayList}&lt;{@link Object}[]&gt;
	 * 
	 * @return ein Array String[]
	 */
	static String[] convertColumnNames(ArrayList<Object[]> zeilenListe) {
		if (zeilenListe == null || zeilenListe.size() < 1
				|| zeilenListe.get(0).length < 1)
			return null;
		Object[] zeile = zeilenListe.get(0);
		String[] columnNames = new String[zeile.length];
		for (int i = 0; i < zeile.length; i++)
			columnNames[i] = (String) zeile[i];
		return columnNames;
	}

	/**
	 * Die Methode soll die Summe aller Gebühren liefern.
	 * 
	 * @param tatbestaende
	 *            ein Array {@link GebuehrenTatbestand}[] mit den angefallenen
	 *            Gebührentatbeständen. Mehrwertsteuer wird ignoriert.
	 * @param streitwert
	 *            ein long mit dem Streitwert
	 * @return ein double mit der Summe der Gebühren für diesen Streitwert
	 */
	static double errechneGebuehrenSumme(GebuehrenTatbestand[] tatbestaende,
			long streitwert) {
		double summe = 0;
		for (GebuehrenTatbestand gt : tatbestaende) {
			/* summe um die Gebühr erhöhen */
			summe += StreitwertReduktion.errechneGebuehr(gt, streitwert);
		}
		return summe;
	}
}
