/**
 * Tenorierend.java
 * eu.gronos.kostenrechner (Kostenrechner)
 */
package eu.gronos.kostenrechner;

/**
 * Das Interface schreibt Klassen vor, zusätzlich zu der Methode String
 * erzeugeTenor() auch Methoden zu Einzeltenoren zu implementieren. Dadurch
 * zeichnet es Klassen aus, die zur Tenorfindung bei Urteilen gebaut sind und so
 * z.B. in eine GUI eingebaut werden können. Das Interface gibt aber auch noch
 * ein paar Konstanten.
 * 
 * @author Peter Schuster (setrok)
 * @date 15.05.2014
 * 
 */
public interface UrteilsTenorierend extends Tenorierend {
	static final String KLAGEABWEISUNG = "Die Klage wird abgewiesen.";
	static final String KLAGEABWEISUNG_ZEILE = "Die Klage wird abgewiesen.\n";
	static final String KLAGEABWEISUNG_IM_UEBRIGEN = "Im Übrigen wird die Klage abgewiesen.";
	static final String KLAGEABWEISUNG_IM_UEBRIGEN_LEERSCHRITT = " Im Übrigen wird die Klage abgewiesen.";
	static final String VERURTEILUNGS_FORMAT = "%s wird verurteilt, %s %,.2f EUR zu zahlen. ";
	static final String VERURTEILUNG_ZAHLUNG_AN_GGF_TEILABWEISUNG_FORMAT = "%s wird verurteilt, an %s %,.2f EUR zu zahlen.%s%n";
	static final String DARUEBER_HINAUS = " darüber hinaus";
	static final String GESAMTSCHULDNERISCH_DARUEBER_FALSCH = "gesamtschuldnerisch werden darüber hinaus verurteilt,";
	static final String GESAMTSCHULDNERISCH_DARUEBER_RICHTIG = "werden darüber hinaus verurteilt, gesamtschuldnerisch";
	static final String GESAMTSCHULDNERISCH_FALSCH = "gesamtschuldnerisch werden verurteilt,";
	static final String GESAMTSCHULDNERISCH_RICHTIG = "werden verurteilt, gesamtschuldnerisch";
	static final String KOSTENTRAGUNG_EINSEITIG = "Die Kosten hat %s zu tragen.%n";
	static final String KOSTENVERTEILUNG_FORMAT = "Die Kosten haben %s zu %,.2f%% und %s zu %,.2f%% zu tragen. %n";
	static final String DIE_KOSTEN_DES_RECHTSSTREITS_HABEN = "Die Kosten des Rechtsstreits haben ";
	static final String DIE_GERICHTSKOSTEN = "Die Gerichtskosten";
	static final String DIE_GERICHTSKOSTEN_HABEN = "Die Gerichtskosten haben ";
	static final String DIE_AUSSERG_KOSTEN = "Die außergerichtlichen Kosten %s haben ";
	static final String AUSSERGERICHTLICHE_KOSTEN_TEIL = ", die außergerichtlichen Kosten ";
	static final String KOSTENTRAGUNG_SELBST = "Im Übrigen haben die Parteien ihre außergerichtlichen Kosten selbst zu tragen.\n";
	static final String PARTEI_PROZENT_OHNE = "%s %,.2f%%, ";
	static final String PARTEI_ZU_PROZENT = "%s zu %,.2f%%, ";
	static final String ZU_TRAGEN = " zu tragen.\n";
	static final String STREITWERT_FESTGESETZT_EINFACH = "Der Streitwert wird auf %,.2f EUR festgesetzt. ";
	static final String STREITWERTFESTSETZUNG_FORMAT = "Der Streitwert wird auf %,.2f EUR bis zum ..., danach auf %,.2f EUR festgesetzt.%n";
	static final String STREITWERT_KLAGE = "Der Streitwert wird auf %,.2f EUR festgesetzt.%n";
	static final String STREITWERT_KLAGE_WIDERKLAGE = "Der Streitwert wird auf %,.2f EUR, für die Klage auf %,.2f EUR, für die Widerklage auf %,.2f EUR festgesetzt.%n";
	static final String FEHLER_REIHENFOLGE_BETEILIGTE = "Die Beteiligten müssen in der Reihenfolge Kläger, Drittwiderbeklagte (sofern vorhanden), Beklagte übergeben werden. \nBitte Programmierer benachrichtigen!";
	static final String FEHLER_NUR_EINER = "Derzeit wird nicht mehr als ein Kläger bzw. ein widerklagender Beklagter unterstützt.";
	static final String FEHLER_NIX_WIDERKLAEGER = "Es wurden widerbeklagte Kläger / Drittwiderbeklagte, aber kein widerklagender Beklagter gefunden.";
	static final String FEHLER_NIX_WIDERBEKLAGTE = "Es wurde ein widerklagender Beklagter, aber kein widerbeklagter Kläger / Drittwiderbeklagter gefunden.";
	static final String FEHLER_NIX_PARTEIEN = "Die BaumbachBeteiligtenListe baumbachBeteiligtenListe muss mindestens einen KLAEGER und einen BEKLAGTEn enthalten!";
	static final String FEHLER_GAR_NIX_PARTEIEN = "baumbachBeteiligtenListe darf nicht null und nicht leer sein!";
	static final String FEHLER_REIHENFOLGE_VERURTEILUNG = "Die verurteilung darf nicht größer als der spätere streitwert sein!";
	static final String FEHLER_REIHENFOLGE_STREITWERTE = "Der spätere Streitwert darf nicht größer als der frühere sein!";
	static final String FEHLER_REIHENFOLGE_FORDERUNGEN = "Die Reihenfolge (erst Klageforderungen, dann Aufrechnungsforderungen) ist nicht eingehalten!";
	static final String FEHLER_FORDERUNG_LEER = "Die Liste der Forderungen darf nicht null oder leer sein!";
	static final String WIRD = "wird";
	static final String WERDEN = "werden";
	static final String HAT = " hat ";
	static final String HABEN = " haben ";
	static final String KOMMA = ", ";
	static final String UND = " und ";
	static final String GRUENDE_UEBERSCHRIFT = "Entscheidungsgründe\n";
	static final String KOSTENENTSCHEIDUNG_91 = "Die Kostenentscheidung beruht auf § 91 ZPO.\n";
	static final String KOSTENENTSCHEIDUNG_91_92_II = "Die Kostenentscheidung beruht auf §§ 91, 92 Abs. 2 ZPO.\n";
	static final String KOSTENENTSCHEIDUNG_92_II = "Die Kostenentscheidung beruht auf § 92 Abs. 1 ZPO.\n";
	static final String EURO_FORMAT = "%,.2f EUR";

	/**
	 * Kostentatbestände, die üblicherweise auf Klägerseite anfallen:
	 * Gerichtskosten, Verfahrensgebühr, Terminsgebühr.
	 */
	static final GebuehrenTatbestand[] KOSTEN_KLAEGER = new GebuehrenTatbestand[] {
			GerichtsGebuehrenTabelle.KV1210, AnwaltsGebuehrenTabelle.VV3100,
			AnwaltsGebuehrenTabelle.VV3104 };

	/**
	 * Kostentatbestände, die üblicherweise auf Beklagtenseite anfallen:
	 * Verfahrensgebühr, Terminsgebühr (keine Gerichtskosten).
	 */
	static final GebuehrenTatbestand[] KOSTEN_BEKLAGTER = new GebuehrenTatbestand[] {
			AnwaltsGebuehrenTabelle.VV3100, AnwaltsGebuehrenTabelle.VV3104 };
	static final String URTEIL_VORLAEUFIG_VOLLSTRECKBAR_709 = "Das Urteil ist gegen Sicherheitsleistung in Höhe von 110% des jeweils zu vollstreckenden Betrags vorläufig vollstreckbar.\n";
	static final String URTEIL_VORLAEUFIG_VOLLSTRECKBAR_709_KOMBI = "Gegenüber %s ist das Urteil gegen Sicherheitsleistung in Höhe von 110%% des jeweils zu vollstreckenden Betrags vorläufig vollstreckbar.\n";
	static final String URTEIL_VORLAEUFIG_VOLLSTRECKBAR_708_711 = "%s wird nachgelassen, die Vollstreckung gegen Sicherheitsleistung in Höhe von 110%% des aufgrund des Urteils vollstreckbaren Betrags abzuwenden, wenn nicht %s vor der Vollstreckung Sicherheit in Höhe von 110%% des jeweils zu vollstreckenden Betrags leistet.\n";
	static final String URTEIL_VORLAEUFIG_VOLLSTRECKBAR = "Das Urteil ist vorläufig vollstreckbar.\n";
	static final int BERUFUNGS_GRENZE = 600;
	static final String JEWEILIGER_VOLLSTRECKUNGSGLAEUBIGER = "der jeweilige Vollstreckungsgläubiger";
	static final String JEWEILIGER_VOLLSTRECKUNGSSCHULDNER = "dem jeweiligen Vollstreckungsschuldner";
	static final String URTEIL_VORLAEUFIG_VOLLSTRECKBAR_708_711_WERIST = "%s wird %s nachgelassen, die Vollstreckung gegen Sicherheitsleistung in Höhe von 110%% des aufgrund des Urteils vollstreckbaren Betrags abzuwenden, wenn nicht %s vor der Vollstreckung Sicherheit in Höhe von 110%% des jeweils zu vollstreckenden Betrags leistet.\n";
	static final String URTEIL_VORLAEUFIG_VOLLSTRECKBAR_709_EINZELN = " ist es gegen Sicherheitsleistung in Höhe von 110% des jeweils zu vollstreckenden Betrags vorläufig vollstreckbar.\n";

	/**
	 * Die Methode soll einen Kostentenor erzeugen.
	 * 
	 * @return den Text des Kostentenors als String mit abschließendem
	 *         Zeilenumbruch.
	 */
	abstract String erzeugeKostentenor();

	/**
	 * Die Methode soll einen Hauptsachetenor erzeugen.
	 * 
	 * @return den Text des Hauptsachetenors als String mit abschließendem
	 *         Zeilenumbruch.
	 */
	abstract String erzeugeHauptsachetenor();
	
	/**
	 * Die Methode erzeugt den Tenor zur vorläufigen Vollstreckbarkeit
	 * 
	 * @return einen String
	 */
	abstract String erzeugeVollstreckbarkeitsTenor();

	/**
	 * Die Methode soll eine Streitwertfestsetzung erzeugen.
	 * 
	 * @return den Text der Streitwertfestsetzung als String mit abschließendem
	 *         Zeilenumbruch.
	 */
	abstract String erzeugeStreitwertFestsetzung();

	/**
	 * Die Methode soll eine Begründung für den Tenor zurückgeben, vor allem für
	 * den Kostentenor.
	 * 
	 * @return den Text Gründe/Entscheidungsgründe als String
	 */
	abstract String getGruende();

	// static final String KOSTENTRAGUNG_PROZENT_FORMAT =
	// "Die Kosten haben %s zu %,.2f%% und %s zu %,.2f%% zu tragen.%n";
	// static final String VON_DEN_GERICHTSKOSTEN = "Von den Gerichtskosten";
	// static final String VON_DEN_GERICHTSKOSTEN_HABEN =
	// "Von den Gerichtskosten haben ";
	// static final String VON_DEN_KOSTEN =
	// "Von den außergerichtlichen Kosten %s haben ";
	// static final String AUSSERGERICHTLICHEN_KOSTEN_TEIL =
	// ", den außergerichtlichen Kosten ";
}
